#!/usr/bin/python

import path_config as pc
import sys
sys.path.append(pc.SRC_PATH)
import argparse
import os
import numpy as np
from PIL import Image
from track.Tracker_mask import TrackerMask
import votclass
import utils as ut

#os.environ['CUDA_VISIBLE_DEVICES'] = "4,5,6,7"

WS_PATH = pc.SRC_PATH + 'vot-experiments/vot2020-TRASTmask-ws'
ckpt_path = pc.CKPT_PATH + 'Student.weights'

parser = argparse.ArgumentParser()
parser.add_argument('--resume',
                        default=pc.CKPT_PATH + 'SiamMask_DAVIS.pth',
                        type=str,
                        metavar='PATH', help='path to latest checkpoint of SiamMask (default: none)')
parser.add_argument('--config', 
                   dest='config', 
                   default=pc.SRC_PATH + 'demotrackers/SiamMask/experiments/siammask_sharp/config_davis.json',
                        help='hyper-parameter of SiamMask in json format')
args = parser.parse_args()

tracker = TrackerMask('TRAST', ckpt_path, ['DiMP'], lstm_update=True, gpu_id=0, args=args)

handle = votclass.VOT("mask")
selection = handle.region()

# Process the first frame
imagefile = handle.frame()
if not imagefile:
    sys.exit(0)

image = Image.open(os.path.join(WS_PATH, imagefile))
img = np.array(image)

# mask given by the toolkit ends with the target (zero-padding to the right and down is needed)
mask = ut.make_full_size(selection, (img.shape[1], img.shape[0]))
prev_mask = mask

bbox = ut._rect_from_mask(mask)

tracker.init(image, bbox)

while True:
    imagefile = handle.frame()
    if not imagefile:
        break

    image = Image.open(os.path.join(WS_PATH, imagefile))

    _, mask, _ = tracker.update(image)
    mask = np.uint8(mask)

    if np.all(mask < 1):
        mask = prev_mask
    else:
        prev_mask = mask

    confidence = 1.0

    handle.report(mask, confidence)
